@@ -10,7 +10,7 @@ impl std::error::Error for Error {}
 impl std::fmt::Display for Error {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
         match self {
-            Error::Hafas(e) => write!(f, "Backend error: {}", e),
+            Error::Hafas(e) => write!(f, "Backend error: {e}"),
             Error::Timeout => write!(f, "Timed Out"),
             Error::NotImplemented => write!(f, "Not implemented by this provider"),
         }
